//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[UnionShantenResult](index.md)/[kokushi](kokushi.md)

# kokushi

[common]\

@EncodeDefault

val [kokushi](kokushi.md): [KokushiShantenResult](../-kokushi-shanten-result/index.md)? = null

标准形向听分析结果
